@@ -33,7 +33,7 @@ class Domoticz(IPlugin):
 #
 	def switchlight(self, jsonInput):
 		bodies = ""
-		entity = jsonInput['outcome']['entities']['intent']
+		entity = jsonInput['outcome']['intent']
 		log.msg("entity :  %s" % (entity))		
 		if jsonInput['outcome']['entities']['location']['value'] :
 			location = jsonInput['outcome']['entities']['location']['value']
